# Generated by Django 2.2.12 on 2020-05-30 18:35

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('volunteers', '0002_remove_volunteer_tasks'),
    ]

    operations = [
        migrations.AlterField(
            model_name='task',
            name='category',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='volunteers.TaskCategory'),
        ),
        migrations.AlterField(
            model_name='tasktemplate',
            name='category',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='volunteers.TaskCategory'),
        ),
    ]
