# Generated by Django 2.2.20 on 2021-05-29 15:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('register', '0010_attendee_shipping_address'),
    ]

    operations = [
        migrations.CreateModel(
            name='Address',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('role', models.CharField(choices=[('billing', 'Billing'), ('shipping', 'Shipping')], max_length=32)),
                ('contact', models.CharField(max_length=50)),
                ('company', models.CharField(blank=True, max_length=50)),
                ('line1', models.CharField(max_length=50)),
                ('line2', models.CharField(blank=True, max_length=50)),
                ('city', models.CharField(max_length=50)),
                ('province', models.CharField(max_length=50)),
                ('postal_code', models.CharField(blank=True, max_length=32)),
                ('country', models.CharField(max_length=2)),
                ('phone_number', models.CharField(blank=True, max_length=32)),
                ('attendee', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='addresses', to='register.Attendee')),
            ],
            options={
                'unique_together': {('attendee', 'role')},
            },
        ),
        migrations.RemoveField(
            model_name='attendee',
            name='shipping_address',
        ),
    ]
